# Contributing

PyFLP adheres to the [**Contributor Covenant Code of Conduct**](https://github.com/demberto/PyFLP/blob/master/CODE_OF_CONDUCT.md). Please make sure you have read it and accept it before proceeding further.

## Quickstart

1. Read the [TODO](https://github.com/demberto/PyFLP/blob/master/TODO.md).
2. Do anything to improve testing.
3. Don't forget to update the [docs](https://pyflp.rtfd.io/).
4. Try to make changes which will break FLPInspect and FLPInfo as less as possible, I will make them locked to a particular PyFLP version in the future.
5. PyFLP use the black code style, format your code with it.

More detailed points [here](https://pyflp.rtfd.io/contributing.md).
